@@ -88,15 +88,14 @@ def level_from_number(value):
     return levels.get(n, None)
 
 
-def url_fetch(url, allowed_schemes=('http', 'https')):
-    '''Get the data at the specified URL.
+def url_fetch(url, timeout=1, allowed_schemes=('http', 'https'), verify=True):
+    """Get the data at the specified URL.
 
     The URL must use the http: or https: schemes.
     The file: scheme is also supported if you override
     the allowed_schemes argument.
     Raise an IOError if getting the data fails.
-    '''
-    LOG.info('Fetching data from %s', url)
+    """
 
     components = urllib.parse.urlparse(url)
 
@@ -105,12 +104,12 @@ def url_fetch(url, allowed_schemes=('http', 'https')):
 
     if components.scheme == 'file':
         try:
-            return urllib.request.urlopen(url).read()
+            return urllib.request.urlopen(url, timeout=timeout).read()
         except urllib.error.URLError as uex:
             raise URLFetchError(_('Failed to retrieve data: %s') % uex)
 
     try:
-        resp = requests.get(url, stream=True)
+        resp = requests.get(url, stream=True, verify=verify, timeout=timeout)
         resp.raise_for_status()
 
         # We cannot use resp.text here because it would download the entire
@@ -123,6 +122,11 @@ def url_fetch(url, allowed_schemes=('http', 'https')):
         reader = resp.iter_content(chunk_size=1000)
         result = ""
         for chunk in reader:
+            if six.PY3 and isinstance(chunk, bytes):
+                # in python 2.7, bytes were implicitly converted to strings
+                # in python 3.5 this is no longer the case so we need this
+                # code to manually convert it
+                chunk = chunk.decode('utf-8')
             result += chunk
             if len(result) > cfg.CONF.max_response_size:
                 raise URLFetchError("Data exceeds maximum allowed size (%s"
