@@ -159,7 +159,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         }
         self.patchobject(node_obj.Node, 'update')
 
-    def test__update_name(self):
+    def test_update_name(self):
         profile = server.ServerProfile('t', self.spec)
         cc = mock.Mock()
         profile._computeclient = cc
@@ -170,7 +170,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertIsNone(res)
         cc.server_update.assert_called_once_with('NOVA_ID', name='NEW_NAME')
 
-    def test__update_name_nova_failure(self):
+    def test_update_name_nova_failure(self):
         profile = server.ServerProfile('t', self.spec)
         cc = mock.Mock()
         profile._computeclient = cc
@@ -185,7 +185,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                          six.text_type(ex))
         cc.server_update.assert_called_once_with('NOVA_ID', name='NEW_NAME')
 
-    def test__update_password(self):
+    def test_update_password(self):
         profile = server.ServerProfile('t', self.spec)
         cc = mock.Mock()
         profile._computeclient = cc
@@ -197,7 +197,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         cc.server_change_password.assert_called_once_with(
             'NOVA_ID', 'NEW_PASSWORD')
 
-    def test__update_password_nova_failure(self):
+    def test_update_password_nova_failure(self):
         profile = server.ServerProfile('t', self.spec)
         cc = mock.Mock()
         profile._computeclient = cc
@@ -214,7 +214,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         cc.server_change_password.assert_called_once_with(
             'NOVA_ID', 'NEW_PASSWORD')
 
-    def test__update_metadata(self):
+    def test_update_metadata(self):
         obj = mock.Mock(id='NODE_ID', physical_id='NOVA_ID',
                         cluster_id='CLUSTER_ID', index=456)
         cc = mock.Mock()
@@ -237,7 +237,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             }
         )
 
-    def test___update_metadata_no_change(self):
+    def test__update_metadata_no_change(self):
         obj = mock.Mock(id='NODE_ID')
         profile = server.ServerProfile('t', self.spec)
         cc = mock.Mock()
@@ -250,7 +250,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertIsNone(res)
         self.assertEqual(0, cc.server_metadata_update.call_count)
 
-    def test__update_metadata_nova_failure(self):
+    def test_update_metadata_nova_failure(self):
         obj = mock.Mock(id='NODE_ID', physical_id='NOVA_ID', cluster_id='')
         err = exc.InternalError(code=500, message='Nova Error')
         cc = mock.Mock()
@@ -273,7 +273,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             'NOVA_ID', {'fooa': 'baaar', 'cluster_node_id': 'NODE_ID'}
         )
 
-    def test__update_flavor(self):
+    def test_update_flavor(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         profile = server.ServerProfile('t', self.spec)
@@ -296,7 +296,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             mock.call('NOVA_ID', 'VERIFY_RESIZE'),
             mock.call('NOVA_ID', 'ACTIVE')])
 
-    def test__update_flavor_failed_validation(self):
+    def test_update_flavor_failed_validation(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         profile = server.ServerProfile('t', self.spec)
@@ -314,7 +314,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
 
         mock_validate.assert_called_once_with(obj, 'FLAV', 'update')
 
-    def test__update_flavor_failed_validation_2(self):
+    def test_update_flavor_failed_validation_2(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         profile = server.ServerProfile('t', self.spec)
@@ -338,7 +338,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             mock.call(obj, 'new_flavor', 'update'),
         ])
 
-    def test__update_flavor_same(self):
+    def test_update_flavor_same(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         profile = server.ServerProfile('t', self.spec)
@@ -359,7 +359,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         ])
         self.assertEqual(0, cc.server_resize.call_count)
 
-    def test__update_flavor_resize_failed(self):
+    def test_update_flavor_resize_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         cc.server_resize.side_effect = [
@@ -387,7 +387,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual("Failed in updating server 'NOVA_ID': Resize "
                          "failed.", six.text_type(ex))
 
-    def test__update_flavor_first_wait_for_server_failed(self):
+    def test_update_flavor_first_wait_for_server_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         cc.wait_for_server.side_effect = [
@@ -421,7 +421,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual("Failed in updating server 'NOVA_ID': "
                          "TIMEOUT.", six.text_type(ex))
 
-    def test__update_flavor_resize_failed_revert_failed(self):
+    def test_update_flavor_resize_failed_revert_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         err_resize = exc.InternalError(code=500, message='Resize')
@@ -454,7 +454,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual("Failed in updating server 'NOVA_ID': "
                          "Revert.", six.text_type(ex))
 
-    def test__update_flavor_confirm_failed(self):
+    def test_update_flavor_confirm_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         err_confirm = exc.InternalError(code=500, message='Confirm')
@@ -484,7 +484,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual("Failed in updating server 'NOVA_ID': Confirm.",
                          six.text_type(ex))
 
-    def test__update_flavor_wait_confirm_failed(self):
+    def test_update_flavor_wait_confirm_failed(self):
         obj = mock.Mock(physical_id='NOVA_ID')
         cc = mock.Mock()
         err_wait = exc.InternalError(code=500, message='Wait')
@@ -517,13 +517,15 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual("Failed in updating server 'NOVA_ID': Wait.",
                          six.text_type(ex))
 
-    def test__update_image(self):
+    def test_update_image(self):
         profile = server.ServerProfile('t', self.spec)
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
         cc = mock.Mock()
+        cc.server_get.return_value = x_server
         profile._computeclient = cc
-        x_old_image = mock.Mock(id='123')
         x_new_image = mock.Mock(id='456')
-        x_images = [x_new_image, x_old_image]
+        x_images = [x_new_image]
         mock_check = self.patchobject(profile, '_validate_image',
                                       side_effect=x_images)
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -535,13 +537,12 @@ class TestNovaServerUpdate(base.SenlinTestCase):
 
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
-            mock.call(obj, 'FAKE_IMAGE', reason='update')
         ])
         cc.server_rebuild.assert_called_once_with(
             'NOVA_ID', '456', 'new_name', 'new_pass')
         cc.wait_for_server.assert_called_once_with('NOVA_ID', 'ACTIVE')
 
-    def test__update_image_new_image_is_none(self):
+    def test_update_image_new_image_is_none(self):
         profile = server.ServerProfile('t', self.spec)
         obj = mock.Mock(physical_id='NOVA_ID')
         new_spec = copy.deepcopy(self.spec)
@@ -556,7 +557,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                " with image set to None is not supported by Nova.")
         self.assertEqual(msg, six.text_type(ex))
 
-    def test__update_image_new_image_invalid(self):
+    def test_update_image_new_image_invalid(self):
         # NOTE: The image invalid could be caused by a non-existent image or
         # a compute driver failure
         profile = server.ServerProfile('t', self.spec)
@@ -577,14 +578,17 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual(msg, six.text_type(ex))
         mock_check.assert_called_once_with(obj, 'new_image', reason='update')
 
-    def test__update_image_old_image_invalid(self):
+    def test_update_image_old_image_invalid(self):
         # NOTE: The image invalid could be caused by a non-existent image or
         # a compute driver failure
         profile = server.ServerProfile('t', self.spec)
-        profile._computeclient = mock.Mock()
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
+        cc = mock.Mock()
+        cc.server_get.return_value = x_server
+        profile._computeclient = cc
         # _validate_image will always throw EResourceUpdate if driver fails
         results = [
-            mock.Mock(id='NEW_IMAGE'),
             exc.EResourceUpdate(type='server', id='NOVA_ID', message='BAD')
         ]
         mock_check = self.patchobject(profile, '_validate_image',
@@ -602,10 +606,9 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual(msg, six.text_type(ex))
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
-            mock.call(obj, 'FAKE_IMAGE', reason='update')
         ])
 
-    def test__update_image_old_image_is_none_but_succeeded(self):
+    def test_update_image_old_image_is_none_but_succeeded(self):
         old_spec = copy.deepcopy(self.spec)
         del old_spec['properties']['image']
         profile = server.ServerProfile('t', old_spec)
@@ -631,7 +634,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             'NOVA_ID', '456', 'new_name', 'new_pass')
         cc.wait_for_server.assert_called_once_with('NOVA_ID', 'ACTIVE')
 
-    def test__update_image_old_image_is_none_but_failed(self):
+    def test_update_image_old_image_is_none_but_failed(self):
         old_spec = copy.deepcopy(self.spec)
         del old_spec['properties']['image']
         profile = server.ServerProfile('t', old_spec)
@@ -656,13 +659,15 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_check.assert_called_once_with(obj, 'new_image', reason='update')
         cc.server_get.assert_called_once_with('NOVA_ID')
 
-    def test__update_image_updating_to_same_image(self):
+    def test_update_image_updating_to_same_image(self):
         profile = server.ServerProfile('t', self.spec)
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
         cc = mock.Mock()
+        cc.server_get.return_value = x_server
         profile._computeclient = cc
-        x_old_image = mock.Mock(id='123')
         x_new_image = mock.Mock(id='123')
-        x_images = [x_old_image, x_new_image]
+        x_images = [x_new_image]
         mock_check = self.patchobject(profile, '_validate_image',
                                       side_effect=x_images)
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -675,19 +680,20 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertFalse(res)
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
-            mock.call(obj, 'FAKE_IMAGE', reason='update')
         ])
         self.assertEqual(0, cc.server_rebuild.call_count)
         self.assertEqual(0, cc.wait_for_server.call_count)
 
-    def test__update_image_failed_rebuilding(self):
+    def test_update_image_failed_rebuilding(self):
         profile = server.ServerProfile('t', self.spec)
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
         cc = mock.Mock()
+        cc.server_get.return_value = x_server
         cc.server_rebuild.side_effect = exc.InternalError(message='FAILED')
         profile._computeclient = cc
-        x_old_image = mock.Mock(id='123')
         x_new_image = mock.Mock(id='456')
-        x_images = [x_new_image, x_old_image]
+        x_images = [x_new_image]
         mock_check = self.patchobject(profile, '_validate_image',
                                       side_effect=x_images)
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -703,20 +709,21 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                          six.text_type(ex))
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
-            mock.call(obj, 'FAKE_IMAGE', reason='update')
         ])
         cc.server_rebuild.assert_called_once_with(
             'NOVA_ID', '456', 'new_name', 'new_pass')
         self.assertEqual(0, cc.wait_for_server.call_count)
 
-    def test__update_image_failed_waiting(self):
+    def test_update_image_failed_waiting(self):
         profile = server.ServerProfile('t', self.spec)
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
         cc = mock.Mock()
+        cc.server_get.return_value = x_server
         cc.wait_for_server.side_effect = exc.InternalError(message='TIMEOUT')
         profile._computeclient = cc
-        x_old_image = mock.Mock(id='123')
         x_new_image = mock.Mock(id='456')
-        x_images = [x_new_image, x_old_image]
+        x_images = [x_new_image]
         mock_check = self.patchobject(profile, '_validate_image',
                                       side_effect=x_images)
         obj = mock.Mock(physical_id='NOVA_ID')
@@ -732,13 +739,12 @@ class TestNovaServerUpdate(base.SenlinTestCase):
                          six.text_type(ex))
         mock_check.assert_has_calls([
             mock.call(obj, 'new_image', reason='update'),
-            mock.call(obj, 'FAKE_IMAGE', reason='update')
         ])
         cc.server_rebuild.assert_called_once_with(
             'NOVA_ID', '456', 'new_name', 'new_pass')
         cc.wait_for_server.assert_called_once_with('NOVA_ID', 'ACTIVE')
 
-    def test__create_interfaces(self):
+    def test_create_interfaces(self):
         cc = mock.Mock()
         server_obj = mock.Mock()
         cc.server_get.return_value = server_obj
@@ -792,13 +798,13 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_validate.assert_has_calls(validation_calls)
         mock_get_port.assert_called_with(obj, {'port': 'port4'})
         create_calls = [
-            mock.call(server_obj, port='port1_id'),
-            mock.call(server_obj, port='port2_id'),
-            mock.call(server_obj, port='port4_id'),
+            mock.call(server_obj, port_id='port1_id'),
+            mock.call(server_obj, port_id='port2_id'),
+            mock.call(server_obj, port_id='port4_id'),
         ]
         cc.server_interface_create.assert_has_calls(create_calls)
 
-    def test__create_interfaces_failed_getting_server(self):
+    def test_create_interfaces_failed_getting_server(self):
         cc = mock.Mock()
         cc.server_get.side_effect = exc.InternalError(message='Not valid')
         profile = server.ServerProfile('t', self.spec)
@@ -817,7 +823,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         cc.server_get.assert_called_once_with('NOVA_ID')
         self.assertEqual(0, profile._create_ports_from_properties.call_count)
 
-    def test__create_interfaces_failed_validation(self):
+    def test_create_interfaces_failed_validation(self):
         cc = mock.Mock()
         server_obj = mock.Mock()
         cc.server_get.return_value = server_obj
@@ -840,7 +846,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_validate.assert_called_once_with(obj, networks[0], 'update')
         self.assertEqual(0, cc.server_interface_create.call_count)
 
-    def test__delete_interfaces(self):
+    def test_delete_interfaces(self):
         cc = mock.Mock()
         nc = mock.Mock()
         net1 = mock.Mock(id='net1')
@@ -880,7 +886,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             mock.call('port3', ignore_missing=True),
         ])
 
-    def test__delete_interfaces_failed_delete(self):
+    def test_delete_interfaces_failed_delete(self):
         cc = mock.Mock()
         profile = server.ServerProfile('t', self.spec)
         profile._computeclient = cc
@@ -912,7 +918,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
 
     @mock.patch.object(server.ServerProfile, '_update_network_remove_port')
     @mock.patch.object(server.ServerProfile, '_update_network_add_port')
-    def test__update_network(self, mock_create, mock_delete):
+    def test_update_network(self, mock_create, mock_delete):
         obj = mock.Mock(physical_id='FAKE_ID')
 
         old_spec = copy.deepcopy(self.spec)
@@ -1126,7 +1132,13 @@ class TestNovaServerUpdate(base.SenlinTestCase):
     def test_do_update_update_flavor_succeeded(self, mock_update_flavor):
         obj = mock.Mock(physical_id='FAKE_ID')
         profile = server.ServerProfile('t', self.spec)
-        profile._computeclient = mock.Mock()
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
+        cc = mock.Mock()
+        cc.server_get.return_value = x_server
+        gc = mock.Mock()
+        profile._computeclient = cc
+        profile._glanceclient = gc
         new_spec = copy.deepcopy(self.spec)
         new_spec['properties']['flavor'] = 'FAKE_FLAVOR_NEW'
         new_profile = server.ServerProfile('t', new_spec)
@@ -1134,6 +1146,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         res = profile.do_update(obj, new_profile)
         self.assertTrue(res)
         mock_update_flavor.assert_called_with(obj, new_profile)
+        gc.image_find.assert_called_with('FAKE_IMAGE', False)
 
     @mock.patch.object(server.ServerProfile, '_update_flavor')
     def test_do_update_update_flavor_failed(self, mock_update_flavor):
@@ -1142,7 +1155,13 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         mock_update_flavor.side_effect = ex
         obj = mock.Mock(physical_id='NOVA_ID')
         profile = server.ServerProfile('t', self.spec)
-        profile._computeclient = mock.Mock()
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
+        cc = mock.Mock()
+        cc.server_get.return_value = x_server
+        gc = mock.Mock()
+        profile._computeclient = cc
+        profile._glanceclient = gc
         new_spec = copy.deepcopy(self.spec)
         new_spec['properties']['flavor'] = 'FAKE_FLAVOR_NEW'
         new_profile = server.ServerProfile('t', new_spec)
@@ -1155,6 +1174,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
         self.assertEqual("Failed in updating server 'NOVA_ID': "
                          "Flavor Not Found.",
                          six.text_type(ex))
+        gc.image_find.assert_called_with('FAKE_IMAGE', False)
 
     @mock.patch.object(server.ServerProfile, '_update_flavor')
     @mock.patch.object(server.ServerProfile, '_update_network')
@@ -1162,7 +1182,13 @@ class TestNovaServerUpdate(base.SenlinTestCase):
             self, mock_update_network, mock_update_flavor):
         mock_update_network.return_value = True
         profile = server.ServerProfile('t', self.spec)
-        profile._computeclient = mock.Mock()
+        x_image = {'id': '123'}
+        x_server = mock.Mock(image=x_image)
+        cc = mock.Mock()
+        gc = mock.Mock()
+        cc.server_get.return_value = x_server
+        profile._computeclient = cc
+        profile._glanceclient = gc
 
         obj = mock.Mock(physical_id='NOVA_ID')
 
@@ -1174,6 +1200,7 @@ class TestNovaServerUpdate(base.SenlinTestCase):
 
         res = profile.do_update(obj, new_profile)
         self.assertTrue(res)
+        gc.image_find.assert_called_with('FAKE_IMAGE', False)
         mock_update_network.assert_called_with(obj, new_profile)
 
     @mock.patch.object(server.ServerProfile, '_update_password')
